@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "flymake-x" "0.2.0"
+(define-package "flymake-x" "20251020.2034"
   "Simple flymake checker definitions."
   '((emacs   "28.1")
     (flymake "1.0"))
   :url "https://github.com/mkcms/flymake-x"
-  :commit "0f50d49dff71a16a50e53619578a6c64fd6d6be1"
-  :revdesc "v0.2.0-0-g0f50d49dff71"
+  :commit "5476c4d1ff2539da0f9335615678f938b4da95df"
+  :revdesc "5476c4d1ff25"
   :keywords '("languages" "tools")
   :authors '(("Michał Krzywkowski" . "k.michal@zoho.com"))
   :maintainers '(("Michał Krzywkowski" . "k.michal@zoho.com")))
